summaryrefslogtreecommitdiffstats
path: root/kcoloredit/kcoloredit.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:51 -0600
commit65eca7929c22f0f0bc64135c02d85d1243df376c (patch)
tree5b47361590fb6693a0f6258d6a8d725856ef2ad9 /kcoloredit/kcoloredit.h
parentcd6d514066c22206c388eddbb7fbec32648dbaeb (diff)
downloadtdegraphics-65eca7929c22f0f0bc64135c02d85d1243df376c.tar.gz
tdegraphics-65eca7929c22f0f0bc64135c02d85d1243df376c.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kcoloredit/kcoloredit.h')
-rw-r--r--kcoloredit/kcoloredit.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/kcoloredit/kcoloredit.h b/kcoloredit/kcoloredit.h
index 59969965..557cdc02 100644
--- a/kcoloredit/kcoloredit.h
+++ b/kcoloredit/kcoloredit.h
@@ -41,17 +41,17 @@ class KColorEditView;
* window and reads the config file as well as providing a menubar, toolbar
* and statusbar. An instance of KColorEditView creates your center view, which is connected
* to the window's Doc object.
* KColorEditApp reimplements the methods that KMainWindow provides for main window handling and supports
* full session management as well as keyboard accelerator configuration by using KAccel.
* @see KMainWindow
* @see TDEApplication
* @see TDEConfig
- * @see KAccel
+ * @see TDEAccel
*
* @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
* @version KDevelop version 0.4 code generation
*/
-class KColorEditApp : public KMainWindow
+class KColorEditApp : public TDEMainWindow
{
Q_OBJECT
@@ -68,7 +68,7 @@ class KColorEditApp : public KMainWindow
/** opens a file specified by commandline option
*/
void openDocumentFile(const char *_cmdl=0);
/** returns a pointer to the current document connected to the KMainWindow instance and is used by
* the View class to access the document object's methods
*/
KColorEditDoc *document() const;
@@ -92,21 +92,21 @@ class KColorEditApp : public KMainWindow
* @see initView();
*/
void initDocument();
/** creates the centerwidget of the KMainWindow instance and sets it as the view
*/
void initView();
/** queryClose is called by KMainWindow on each closeEvent of a window. Against the
* default implementation (only returns true), this calles saveModified() on the document object to ask if the document shall
* be saved if Modified; on cancel the closeEvent is rejected.
- * @see KMainWindow#queryClose
- * @see KMainWindow#closeEvent
+ * @see TDEMainWindow#queryClose
+ * @see TDEMainWindow#closeEvent
*/
virtual bool queryClose();
/** queryExit is called by KMainWindow when the last window of the application is going to be closed during the closeEvent().
* Against the default implementation that just returns true, this calls saveOptions() to save the settings of the last window's
* properties.
- * @see KMainWindow#queryExit
- * @see KMainWindow#closeEvent
+ * @see TDEMainWindow#queryExit
+ * @see TDEMainWindow#closeEvent
*/
virtual bool queryExit();
@@ -168,9 +168,9 @@ class KColorEditApp : public KMainWindow
/** the configuration object of the application */
TDEConfig *config;
- KAction *m_actSave, *m_actCut, *m_actCopy, *m_actPaste, *m_actPalette;
- KToggleAction *m_actNames;
- KRecentFilesAction *m_actRecent;
+ TDEAction *m_actSave, *m_actCut, *m_actCopy, *m_actPaste, *m_actPalette;
+ TDEToggleAction *m_actNames;
+ TDERecentFilesAction *m_actRecent;
/** view is the main widget which represents your working area. The View
* class should handle all events of the view widget. It is kept empty so
@@ -41,17 +41,17 @@ class KColorEditView;
* and statusbar. An instance of KColorEditView creates your center view, which is connected
* to the window's Doc object.
- * KColorEditApp reimplements the methods that KMainWindow provides for main window handling and supports
- * full session management as well as keyboard accelerator configuration by using KAccel.
- * @see KMainWindow
+ * KColorEditApp reimplements the methods that TDEMainWindow provides for main window handling and supports
+ * full session management as well as keyboard accelerator configuration by using TDEAccel.
+ * @see TDEMainWindow
* @see TDEApplication
* @see TDEConfig
@@ -68,7 +68,7 @@ class KColorEditApp : public KMainWindow
*/
void openDocumentFile(const char *_cmdl=0);
- /** returns a pointer to the current document connected to the KMainWindow instance and is used by
+ /** returns a pointer to the current document connected to the TDEMainWindow instance and is used by
* the View class to access the document object's methods
*/
@@ -92,21 +92,21 @@ class KColorEditApp : public KMainWindow
*/
void initDocument();
- /** creates the centerwidget of the KMainWindow instance and sets it as the view
+ /** creates the centerwidget of the TDEMainWindow instance and sets it as the view
*/
void initView();
@@ -92,21 +92,21 @@ class KColorEditApp : public KMainWindow
*/
void initView();
- /** queryClose is called by KMainWindow on each closeEvent of a window. Against the
+ /** queryClose is called by TDEMainWindow on each closeEvent of a window. Against the
* default implementation (only returns true), this calles saveModified() on the document object to ask if the document shall
* be saved if Modified; on cancel the closeEvent is rejected.
@@ -92,21 +92,21 @@ class KColorEditApp : public KMainWindow
*/
virtual bool queryClose();
- /** queryExit is called by KMainWindow when the last window of the application is going to be closed during the closeEvent().
+ /** queryExit is called by TDEMainWindow when the last window of the application is going to be closed during the closeEvent().
* Against the default implementation that just returns true, this calls saveOptions() to save the settings of the last window's
* properties.